# stm32l1
This crate provides an autogenerated API for access to STM32L1 peripherals.
The API is generated using [svd2rust] with patched svd files containing
extensive type-safe support. For more information please see the [main repo].

Refer to the [documentation] for full details.

[svd2rust]: https://github.com/japaric/svd2rust
[main repo]: https://github.com/stm32-rs/stm32-rs
[documentation]: https://docs.rs/stm32l1/latest/stm32l1/

## Usage
Each device supported by this crate is behind a feature gate so that you only
compile the device(s) you want. To use, in your Cargo.toml:

```toml
[dependencies.stm32l1]
version = "0.9.0"
features = ["stm32l100", "rt"]
```

The `rt` feature is optional and brings in support for `cortex-m-rt`.

In your code:

```rust
use stm32l1::stm32l100;

let mut peripherals = stm32l100::Peripherals::take().unwrap();
let gpioa = &peripherals.GPIOA;
gpioa.odr.modify(|_, w| w.odr0().set_bit());
```

For full details on the autogenerated API, please see:
https://docs.rs/svd2rust/0.16.1/svd2rust/#peripheral-api

## Supported Devices

| Module | Devices | Links |
|:------:|:-------:|:-----:|
| stm32l100 | STM32L100 | [RM0038](https://www.st.com/resource/en/reference_manual/cd00240193.pdf), [st.com](https://www.st.com/en/microcontrollers-microprocessors/stm32l100-value-line.html) |
| stm32l151 | STM32L151, STM32L152 | [RM0038](https://www.st.com/resource/en/reference_manual/cd00240193.pdf), [st.com](https://www.st.com/en/microcontrollers-microprocessors/stm32l151-152.html) |
| stm32l162 | STM32L162 | [RM0038](https://www.st.com/resource/en/reference_manual/cd00240193.pdf), [st.com](https://www.st.com/en/microcontrollers-microprocessors/stm32l162.html) |
